@@ -127,7 +127,7 @@ impl Task {
     }
 }
 
-#[allow(clippy::derive_hash_xor_eq)]
+#[allow(clippy::derived_hash_with_manual_eq)]
 impl Hash for Task {
     fn hash<H: Hasher>(&self, state: &mut H) {
         let mut proto_bytes: Vec<u8> = Vec::with_capacity(self.encoded_len());
@@ -147,7 +147,7 @@ pub trait TaskDependencies {
     }
 }
 
-#[allow(clippy::derive_hash_xor_eq)]
+#[allow(clippy::derived_hash_with_manual_eq)]
 impl Hash for NodeValueIndex {
     fn hash<H: Hasher>(&self, state: &mut H) {
         self.node_index.hash(state);
