@@ -144,7 +144,8 @@ mod test_custom_specs {
         case("custom/gh_391", 0.001, true),
         case("custom/facet_grouped_bar_with_error_bars", 0.001, true),
         case("custom/facet_grouped_bar_with_error_bars_with_sort", 0.001, true),
-        case("custom/binned_ordinal", 0.001, true)
+        case("custom/binned_ordinal", 0.001, true),
+        case("custom/timeOffset_stocks", 0.001, true)
     )]
     fn test_image_comparison(spec_name: &str, tolerance: f64, extract_inline_values: bool) {
         println!("spec_name: {spec_name}");
@@ -1161,7 +1162,7 @@ mod test_image_comparison_window {
 mod test_pre_transform_inline {
     use super::*;
     use crate::util::datasets::vega_json_dataset_async;
-    use vegafusion_core::proto::gen::pretransform::PreTransformInlineDataset;
+    use vegafusion_core::proto::gen::tasks::InlineDataset;
     use vegafusion_sql::connection::datafusion_conn::DataFusionConnection;
 
     #[tokio::test]
@@ -1186,7 +1187,7 @@ mod test_pre_transform_inline {
 
         // Load csv file as inline dataset
         let movies_table = vega_json_dataset_async("movies").await;
-        let inline_datasets = vec![PreTransformInlineDataset {
+        let inline_datasets = vec![InlineDataset {
             name: "movies".to_string(),
             table: movies_table.to_ipc_bytes().unwrap(),
         }];
