@@ -97,20 +97,20 @@ impl DataFrame for SqlDataFrame {
             .and_then(pre_process_column_types)
     }
 
-    async fn sort(&self, expr: Vec<Expr>, limit: Option<i32>) -> Result<Arc<dyn DataFrame>> {
-        fallback_operation!(self, sort, _sort, expr, limit)
+    async fn sort(&self, exprs: Vec<Expr>, limit: Option<i32>) -> Result<Arc<dyn DataFrame>> {
+        fallback_operation!(self, sort, _sort, exprs, limit)
     }
 
-    async fn select(&self, expr: Vec<Expr>) -> Result<Arc<dyn DataFrame>> {
-        fallback_operation!(self, select, _select, expr)
+    async fn select(&self, exprs: Vec<Expr>) -> Result<Arc<dyn DataFrame>> {
+        fallback_operation!(self, select, _select, exprs)
     }
 
     async fn aggregate(
         &self,
-        group_expr: Vec<Expr>,
-        aggr_expr: Vec<Expr>,
+        group_exprs: Vec<Expr>,
+        aggr_exprs: Vec<Expr>,
     ) -> Result<Arc<dyn DataFrame>> {
-        fallback_operation!(self, aggregate, _aggregate, group_expr, aggr_expr)
+        fallback_operation!(self, aggregate, _aggregate, group_exprs, aggr_exprs)
     }
 
     async fn joinaggregate(
@@ -206,7 +206,20 @@ impl SqlDataFrame {
             .collect();
         let select_items = columns.join(", ");
 
-        let table_ident = Ident::with_quote(conn.dialect().quote_style, table).to_string();
+        // Replace special characters with underscores
+        let mut clean_table = table.to_string();
+        for c in &['"', '\'', '.', '-'] {
+            clean_table = clean_table.replace(*c, "_");
+        }
+
+        let quote_style = conn.dialect().quote_style;
+        let table_ident = if !table.starts_with(quote_style) {
+            // Quote table
+            Ident::with_quote(conn.dialect().quote_style, table).to_string()
+        } else {
+            // If table name starts with the quote character, assume already quoted
+            table.to_string()
+        };
 
         let query = parse_sql_query(
             &format!("select {select_items} from {table_ident}"),
@@ -214,7 +227,7 @@ impl SqlDataFrame {
         )?;
 
         Ok(Self {
-            prefix: format!("{table}_"),
+            prefix: format!("{clean_table}_"),
             ctes: vec![query],
             schema: Arc::new(schema),
             conn,
@@ -258,7 +271,7 @@ impl SqlDataFrame {
                     }
 
                     expr_selects.push(Select {
-                        distinct: false,
+                        distinct: None,
                         top: None,
                         projection,
                         into: None,
@@ -270,6 +283,7 @@ impl SqlDataFrame {
                         distribute_by: Default::default(),
                         sort_by: Default::default(),
                         having: None,
+                        named_window: Default::default(),
                         qualify: None,
                     });
                 }
@@ -357,7 +371,7 @@ impl SqlDataFrame {
                 };
 
                 let select_body = SetExpr::Select(Box::new(Select {
-                    distinct: false,
+                    distinct: None,
                     top: None,
                     projection,
                     into: None,
@@ -377,6 +391,7 @@ impl SqlDataFrame {
                     sort_by: Default::default(),
                     having: None,
                     qualify: None,
+                    named_window: Default::default(),
                 }));
                 Query {
                     with: None,
@@ -438,9 +453,9 @@ impl SqlDataFrame {
         .unwrap()
     }
 
-    async fn _sort(&self, expr: Vec<Expr>, limit: Option<i32>) -> Result<Arc<dyn DataFrame>> {
+    async fn _sort(&self, exprs: Vec<Expr>, limit: Option<i32>) -> Result<Arc<dyn DataFrame>> {
         let mut query = self.make_select_star();
-        let sql_exprs = expr
+        let sql_exprs = exprs
             .iter()
             .map(|expr| expr.to_sql_order(self.dialect(), &self.schema_df()?))
             .collect::<Result<Vec<_>>>()?;
@@ -455,8 +470,8 @@ impl SqlDataFrame {
         self.chain_query(query, self.schema.as_ref().clone())
     }
 
-    async fn _select(&self, expr: Vec<Expr>) -> Result<Arc<dyn DataFrame>> {
-        let sql_expr_strs = expr
+    async fn _select(&self, exprs: Vec<Expr>) -> Result<Arc<dyn DataFrame>> {
+        let sql_expr_strs = exprs
             .iter()
             .map(|expr| {
                 Ok(expr
@@ -477,21 +492,21 @@ impl SqlDataFrame {
 
         // Build new schema
         let new_schema =
-            make_new_schema_from_exprs(self.schema.as_ref(), expr.as_slice(), self.dialect())?;
+            make_new_schema_from_exprs(self.schema.as_ref(), exprs.as_slice(), self.dialect())?;
 
         self.chain_query(query, new_schema)
     }
 
     async fn _aggregate(
         &self,
-        group_expr: Vec<Expr>,
-        aggr_expr: Vec<Expr>,
+        group_exprs: Vec<Expr>,
+        aggr_exprs: Vec<Expr>,
     ) -> Result<Arc<dyn DataFrame>> {
         // Add group exprs to aggregates for SQL query
-        let mut all_aggr_expr = aggr_expr;
-        all_aggr_expr.extend(group_expr.clone());
+        let mut all_aggr_expr = aggr_exprs;
+        all_aggr_expr.extend(group_exprs.clone());
 
-        let sql_group_expr_strs = group_expr
+        let sql_group_expr_strs = group_exprs
             .iter()
             .map(|expr| Ok(expr.to_sql(self.dialect(), &self.schema_df()?)?.to_string()))
             .collect::<Result<Vec<_>>>()?;
